@@ -1,6 +1,4 @@
-from elementmaster import ElementMaster, alphabet
 from PyQt5.QtCore import Qt, QCoreApplication, pyqtSignal, QVariant
-from PyQt5.QtGui import  QPixmap, QPainter, QColor
 from PyQt5.QtWidgets import (QVBoxLayout, QHBoxLayout, QLabel, QTextEdit, QWidget, QComboBox, QCheckBox,
                                 QPushButton, QStackedWidget)
 from PyQt5.QtCore import QCoreApplication as QC
@@ -8,7 +6,7 @@ import logging
 import os.path
 from time import sleep
 from datetime import datetime
-from Pythonic.elementmaster import alphabet
+from Pythonic.elementmaster import ElementMaster, alphabet
 from Pythonic.elementeditor import ElementEditor
 from Pythonic.record_function import Record, Function
 
@@ -22,10 +20,9 @@ class ExecReturn(ElementMaster):
     def __init__(self, row, column):
         self.row = row
         self.column = column
-
         # grid, wrk_selecctor_index, wrk_pos, ischecked
         self.config = (0, 0, (0,0), False)
-        super().__init__(self.row, self.column, QPixmap(self.pixmap_path), True, self.config)
+        super().__init__(self.row, self.column, self.pixmap_path, True, self.config)
         super().edit_sig.connect(self.edit)
         logging.debug('ExecReturn called at row {}, column {}'.format(row, column))
 
@@ -34,7 +31,7 @@ class ExecReturn(ElementMaster):
     def __setstate__(self, state):
         logging.debug('__setstate__() called ExecReturn')
         self.row, self.column, self.config = state
-        super().__init__(self.row, self.column, QPixmap(self.pixmap_path), True, self.config)
+        super().__init__(self.row, self.column, self.pixmap_path, True, self.config)
         super().edit_sig.connect(self.edit)
         self.addFunction(ReturnFunction)
 
@@ -112,16 +109,18 @@ class ExecReturn(ElementMaster):
         self.returnEdit.setLayout(self.returnEditLayout)
         self.returnEdit.show()
 
-    def baustelle(self, config):
+    def recvGridConfig(self, config):
 
         self.wrk_selectors_arr = []
-
-        logging.debug('ExecReturn::baustelle config: {}'.format(config))
+        logging.debug('ExecReturn::recvGridConfig config: {}'.format(config))
         for index, wrk_area in enumerate(config):
             self.grid_selector.addItem('Grid {}'.format(index + 1))
+            logging.debug('ExecReturn::recvGridConfig Grid: {}'.format(index + 1))
 
             self.wrk_selectors_arr.append(QComboBox())
+            logging.debug('ExecReturn::recvGridConfig flag: {}'.format(1))
             self.element_selector.addWidget(self.wrk_selectors_arr[index])
+            logging.debug('ExecReturn::recvGridConfig flag: {}'.format(1))
             for pos in wrk_area:
                 self.wrk_selectors_arr[index].addItem('{} {}'.format(pos[0], alphabet[pos[1]]), QVariant(pos))
 
@@ -133,20 +132,20 @@ class ExecReturn(ElementMaster):
 
     def loadLastConfig(self):
 
-        grid, wrk_selecctor_index, wrk_pos, log_state = self.config
+        grid, wrk_selector_index, wrk_pos, log_state = self.config
 
         self.grid_selector.setCurrentIndex(grid)
         self.element_selector.setCurrentIndex(grid)
-        self.wrk_selectors_arr[grid].setCurrentIndex(wrk_selecctor_index)
+        self.wrk_selectors_arr[grid].setCurrentIndex(wrk_selector_index)
         self.log_checkbox.setChecked(log_state)
 
     def edit_done(self):
         logging.debug('edit_done() called ExecReturn' )
         grid = self.grid_selector.currentIndex()
-        wrk_selecctor_index = self.wrk_selectors_arr[grid].currentIndex()
+        wrk_selector_index = self.wrk_selectors_arr[grid].currentIndex()
         wrk_pos = self.wrk_selectors_arr[grid].currentData()
 
-        self.config = (grid, wrk_selecctor_index, wrk_pos, self.log_checkbox.isChecked())
+        self.config = (grid, wrk_selector_index, wrk_pos, self.log_checkbox.isChecked())
         self.addFunction(ReturnFunction)
 
 class ReturnFunction(Function):
@@ -158,7 +157,7 @@ class ReturnFunction(Function):
 
         grid, wrk_selecctor_index, wrk_pos, log_state = self.config
         target_0 = (grid, wrk_pos[0], wrk_pos[1])
-        log_txt = '{{BASIC RETURN}}           Grid {} - Pos {}|{}'.format(grid, wrk_pos[0], alphabet[wrk_pos[1]])
+        log_txt = '{{BASIC RETURN}}           Grid {} - Pos {}|{}'.format(grid+1, wrk_pos[0], alphabet[wrk_pos[1]])
         result = Record(self.getPos(), target_0, record, log=log_state, log_txt=log_txt)
         return result
 
