@@ -1,12 +1,11 @@
-from elementmaster import ElementMaster, alphabet
 from PyQt5.QtCore import Qt, QCoreApplication, pyqtSignal, QVariant
-from PyQt5.QtGui import  QPixmap, QPainter, QColor, QIntValidator
+from PyQt5.QtGui import  QIntValidator
 from PyQt5.QtWidgets import (QVBoxLayout, QHBoxLayout, QLabel, QTextEdit, QWidget, QComboBox, QCheckBox, QFileDialog, QPushButton, QStackedWidget, QLineEdit)
 from PyQt5.QtCore import QCoreApplication as QC
 import logging, pickle, os
 from time import sleep
 from datetime import datetime
-from Pythonic.elementmaster import alphabet
+from Pythonic.elementmaster import ElementMaster, alphabet
 from Pythonic.record_function import Record, Function
 from Pythonic.elementeditor import ElementEditor
 from Pythonic.elements.basic_stack_window import StackWindow
@@ -34,7 +33,7 @@ class ExecStack(ElementMaster):
         log_state = False
         self.config = (filename, read_mode, write_mode, delete_read,
                 b_array_limits, n_array_limits, log_state)
-        super().__init__(self.row, self.column, QPixmap(self.pixmap_path), True, self.config)
+        super().__init__(self.row, self.column, self.pixmap_path, True, self.config)
         super().edit_sig.connect(self.edit)
         logging.debug('ExecStack called at row {}, column {}'.format(row, column))
 
@@ -43,7 +42,7 @@ class ExecStack(ElementMaster):
     def __setstate__(self, state):
         logging.debug('__setstate__() called ExecStack')
         self.row, self.column, self.config = state
-        super().__init__(self.row, self.column, QPixmap(self.pixmap_path), True, self.config)
+        super().__init__(self.row, self.column, self.pixmap_path, True, self.config)
         super().edit_sig.connect(self.edit)
         self.addFunction(StackFunction)
 
