@@ -1,12 +1,12 @@
 from PyQt5.QtCore import Qt, QCoreApplication, pyqtSignal, QVariant
-from PyQt5.QtGui import  QPixmap, QPainter, QColor, QIntValidator, QDoubleValidator
+from PyQt5.QtGui import  QDoubleValidator
 from PyQt5.QtWidgets import QVBoxLayout, QHBoxLayout, QLineEdit, QPushButton, QLabel, QTextEdit, QWidget, QComboBox, QCheckBox, QStackedWidget
-from elementeditor import ElementEditor
 from PyQt5.QtCore import QCoreApplication as QC
 from pythonic_binance.client import Client
 import pandas as pd
 import os.path, datetime, logging
 from time import sleep
+from Pythonic.elementeditor import ElementEditor
 from Pythonic.record_function import Record, Function
 from Pythonic.elementmaster import ElementMaster
 
@@ -33,7 +33,7 @@ class BinanceOrder(ElementMaster):
         self.config = (pub_key, prv_key, side_index, side_txt, symbol_txt, \
                 quantity, order_index, order_string, order_config, log_state)
 
-        super().__init__(self.row, self.column, QPixmap(self.pixmap_path), True, self.config)
+        super().__init__(self.row, self.column, self.pixmap_path, True, self.config)
         super().edit_sig.connect(self.edit)
         logging.debug('BinanceOrder::__init__() called at row {}, column {}'.format(row, column))
         self.addFunction(BinanceOrderFunction)
@@ -41,7 +41,7 @@ class BinanceOrder(ElementMaster):
     def __setstate__(self, state):
         logging.debug('__setstate__() called BinanceOrder')
         self.row, self.column, self.config = state
-        super().__init__(self.row, self.column, QPixmap(self.pixmap_path), True, self.config)
+        super().__init__(self.row, self.column, self.pixmap_path, True, self.config)
         super().edit_sig.connect(self.edit)
         self.addFunction(BinanceOrderFunction)
 
